@@ -91,7 +91,6 @@ class PythonInfo(object):
         self.system_stdlib_platform = self.sysconfig_path("platstdlib", confs)
         self.max_size = getattr(sys, "maxsize", getattr(sys, "maxint", None))
         self._creators = None
-        self._stdlib_paths = None
 
     def _fast_get_system_executable(self):
         """Try to get the system executable by just looking at properties"""
@@ -112,6 +111,8 @@ class PythonInfo(object):
     def _distutils_install():
         # follow https://github.com/pypa/pip/blob/master/src/pip/_internal/locations.py#L95
         d = Distribution({"script_args": "--no-user-cfg"})  # configuration files not parsed so they do not hijack paths
+        if hasattr(sys, "_framework"):
+            sys._framework = None  # disable macOS static paths for framework
         i = d.get_command_obj("install", create=True)
         i.prefix = os.sep  # paths generated are relative to prefix that contains the path sep, this makes it relative
         i.finalize_options()
@@ -276,7 +277,7 @@ class PythonInfo(object):
         return json.dumps(self._to_dict(), indent=2)
 
     def _to_dict(self):
-        data = {var: (getattr(self, var) if var not in ("_creators", "_stdlib_paths") else None) for var in vars(self)}
+        data = {var: (getattr(self, var) if var not in ("_creators",) else None) for var in vars(self)}
         # noinspection PyProtectedMember
         data["version_info"] = data["version_info"]._asdict()  # namedtuple to dictionary
         return data
@@ -417,7 +418,7 @@ class PythonInfo(object):
 
         # or at root level
         candidate_folder[inside_folder] = None
-        return list(candidate_folder.keys())
+        return list(i for i in candidate_folder.keys() if os.path.exists(i))
 
     def _find_possible_exe_names(self):
         name_candidate = OrderedDict()
@@ -451,19 +452,6 @@ class PythonInfo(object):
                 if upper != base:
                     yield upper
 
-    def stdlib_path(self, name):
-        if self._stdlib_paths is None:
-            from collections import OrderedDict
-            from virtualenv.util.path import Path
-
-            pat = OrderedDict((Path(i), None) for i in (self.system_stdlib, self.system_stdlib_platform))
-            self._stdlib_paths = list(pat.keys())
-        for path in self._stdlib_paths:
-            std_path = path / name
-            if std_path.exists():
-                return std_path
-        return self._stdlib_paths[0] / name
-
 
 if __name__ == "__main__":
     # dump a JSON representation of the current python
